@@ -2,10 +2,10 @@ use super::{NodeOrValueIter, Queryable, Value, ValueIter};
 use arrayvec::{Array, ArrayVec};
 use std::convert::TryFrom;
 
-impl<'q, T> Queryable<'q> for ArrayVec<T>
+impl<T> Queryable for ArrayVec<T>
 where
     T: Array,
-    <T as Array>::Item: Queryable<'q>,
+    <T as Array>::Item: Queryable,
 {
     fn name(&self) -> &'static str {
         "ArrayVec"
@@ -13,11 +13,11 @@ where
     fn keys(&self) -> ValueIter<'_> {
         ValueIter::from_values(0..self.len())
     }
-    fn member<'a, 'f>(&'a self, field: &'f Value) -> Option<&'a dyn Queryable<'q>> {
+    fn member<'f>(&self, field: &'f Value) -> Option<&dyn Queryable> {
         let index = usize::try_from(field).ok()?;
         self.get(index).map(|v| v as _)
     }
-    fn all<'a>(&'a self) -> NodeOrValueIter<'a, 'q> {
+    fn all(&self) -> NodeOrValueIter<'_> {
         NodeOrValueIter::from_queryables(self)
     }
 }
